/*
  Vocatra, a small and fast vocabulary trainer
  Copyright (C) 2006-2008 Oliver Sauder <os@esite.ch>
  
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef _VOCATRAINFO_H
#define _VOCATRAINFO_H

/** Vocatra Information class
 *  This class provides information and help methods about Vocatra.
 */
class CVocatraInfo
{
private:
	/** Static helper function.
	 *  This function breaks a string into lines with the length of <= 70 characters.
	 *  @param str this string will be broken into lines
	 *  @param bIndent If true, indent new lines with 49 spaces. (needed to create man page)
	 *  @return string with added \n characters and optinal indentation.
	 */
	static std::string breakString(const std::string &str,const bool &bIndent=false);

public:
	/** Print Usage function.
	 *  This function prints the usage string to the stdout.
	 *  @param bPrintHelp prints "try vocatra --help ..."-string if true
	 */
	static void PrintUsage(const bool &bPrintHelp=true);

	/** Print Help function.
	 *  This function prints the help to the stdout.
	 */
	static void PrintHelp();

	/** Print Version function.
	 *  This function prints the version number to the stdout.
	 */
	static void PrintVersion();

	/** Get Name function.
	 *  This function returns the package name.
	 *  Default: vocatra
	 */
	static const char* GetName();

	/** Get Order Mode function.
	 *  This function returns the string from the order mode.
	 *  Default: order
	 */
	static const char* GetOrderMode();

	/** Get Random Mode function.
	 *  This function returns the string from the random mode.
	 *  Default: random
	 */
	static const char* GetRandomMode();

	/** Get Alphabetical Mode function
	 *  This function returns the string from the alphabetical mode.
	 *  Default: alphabetical
	 */
	static const char* GetAlphabeticalMode();
  
	/** Get Left Language function.
	 *  This function returns the string from the left language.
	 *  Default: left
	 */
	static const char* GetLeftLang();

	/** Get Right Language function.
	 *  This function returns the string from the right language.
	 *  Default: right
	 */
	static const char* GetRightLang();
};

#endif // _VOCATRAINFO_H
