/*
  Vocatra, a small and fast vocabulary trainer
  Copyright (C) 2006-2008 Oliver Sauder <os@esite.ch>
  
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#include <stdio.h>

#include "vocatra.H"
#include "vocatrainfo.H"

using namespace std;

std::string CVocatraInfo::breakString(const std::string &str,const bool &bIndent)
{
	string sSpaces(49,' ');
	string sResult = "";
	int nPosLastSpace = 0;
	int nCountLines = 1;
	int nAlreadyCopied = 0;
	const int POS_BREAK = 70;

	for(size_t i=0;i<str.size();++i)
	{
		if(i==nCountLines*POS_BREAK)
		{
			if(bIndent)
			{
				sResult += sSpaces;
			}
			sResult += str.substr(nAlreadyCopied,nPosLastSpace-nAlreadyCopied);
			sResult += '\n';
			nAlreadyCopied = nPosLastSpace+1;
			++nCountLines;
		}

		if(str[i]==' ')
		{
			nPosLastSpace = i;
		}
	}

	// add remaining string to result (indent first if necessary)
	if(bIndent)
	{
		sResult += sSpaces;
	}
	sResult += str.substr(nAlreadyCopied,str.npos);

	return sResult;
}

void CVocatraInfo::PrintUsage(const bool &bPrintHelp)
{
	// %s = name of package (usually vocatra)
	fprintf(stdout, _("Usage: %s [OPTIONS]... VOC-FILE..."), GetName());
	cout << endl;

	if(bPrintHelp)
	{
		fprintf(stdout, _("Try '%s --help' for more information."), GetName());
		cout << endl;
	}
}

void CVocatraInfo::PrintHelp()
{
	// %s = name of package (usually vocatra)
	fprintf(stdout, breakString(_("`%s' is a console-based vocabulary trainer. It takes one or more "
								  "vocabulary files, queries you for each word and lets you try to give "
								  "the correct answer. You can enable different learning modes. If you "
								  "prefer to learn sequentially it has an order mode. Otherwise, there is "
								  "also a random mode available.")).c_str(), GetName());
	cout << endl;
	cout << endl;

	PrintUsage(false);
	cout << endl;

	cout << _("Options") << ":" << endl;

	// beep
	cout << " -b --beep                                       ";
	cout << _("beep if answer is wrong") << endl << endl;
	cout << breakString(_("If this option is enabled and you still cannot hear a beep sound, "
						  "your system speaker might be turned off."), true);
	cout << endl;

	// no case
	cout << " -c --nocase                                     ";
	cout << _("compare case-insensitively") << endl;

	// debug
	cout << " -d --debug                                      ";
	cout << _("enable debug mode") << endl;

	// help
	cout << " -h --help                                       ";
	cout << _("display this help and exit") << endl;

	// language
	cout << " -l --language={left(1),right(2)}                ";
	cout << _("specify the inquiry language (default: left)") << endl;

	// mode
	cout << " -m --mode={order(1)|random(2)|alphabetical(3)}  ";
	cout << _("specify the inquiry mode (default: order)") << endl;

    // passes
	cout << " -p --passes=number                              ";
	cout << _("define number of passes (default: 1)") << endl;

	// stack
	cout << " -s --stack                                      ";
	cout << _("enable stack-by-stack mode") << endl << endl;
	cout << breakString(_("You have a stack of vocabulary cards. "
						  "If you translate a word correctly, the card moves to a new stack. "
						  "You will learn on the current stack until it is empty."), true);
	cout << endl;

	// synonym
	cout << " -y --synonym                                    ";
	cout << _("query each synonym once per pass") << endl;
	
	// version
	cout << " -v --version                                    ";
	cout << _("print version number and exit") << endl;
	cout << endl;
	cout << _("Report bugs to <vocatra@esite.ch> or directly on SourceForge") << endl;
}

void CVocatraInfo::PrintVersion()
{
	cout << GetName() << " " << VERSION << endl;
	cout << endl;

	cout << "Copyright (C) 2008 Esite <webmaster@esite.ch>" << endl;
	cout << endl;

	cout << "Written by Oliver Sauder <os@esite.ch>" << endl;
	cout << endl;
}

const char* CVocatraInfo::GetName()
{
	return PACKAGE;
}

const char* CVocatraInfo::GetOrderMode()
{
	return "order";
}

const char* CVocatraInfo::GetRandomMode()
{
	return "random";
}

const char* CVocatraInfo::GetAlphabeticalMode()
{
	return "alphabetical";
}

const char* CVocatraInfo::GetLeftLang()
{
	return "left";
}

const char* CVocatraInfo::GetRightLang()
{
	return "right";
}
