/*
  Vocatra, a small and fast vocabulary trainer
  Copyright (C) 2006-2008 Oliver Sauder <os@esite.ch>
  
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#include <fstream>
#include "vocatra.H"
#include "vocatrainfo.H"
#include "vocfile.H"

using namespace std;

CVocFile::CVocFile(char *filename)
	: m_strFilename(filename)
{
}

void CVocFile::trim(std::string &str)
{
	const char* const delims=" \t";

	size_t index=str.find_last_not_of(delims);
	if(index!=string::npos)
		str.erase(++index);

	index=str.find_first_not_of(delims);
	if(index!=string::npos) {
		str.erase(0,index);
	}
	else {
		str.erase();
	}
}

size_t CVocFile::checkLine(std::string &line)
{
	trim(line);
	size_t pos=line.find("=");

	if(line.empty()||line.find("#")==0)
    {
		pos=0; // comment or a empty line
    }
	// check line format (lang1,..=lang2,..
	else if(pos==string::npos||pos==0||pos==line.size()-1
			||line.substr(0,pos).find("0")!=string::npos
			||line.substr(pos+1,line.size()-1).find("=")!=string::npos)
    {
		pos=string::npos; // unexpected line
    }

	return pos;
}

void CVocFile::seperateWords(std::string str,std::vector<std::string> &words)
{
	size_t pos;
	words.clear();

	while((pos=str.find(","))!=string::npos)
    {
		string word=str.substr(0,pos);
		trim(word);

		words.push_back(word);
		str.erase(0,pos+1);
    }

	trim(str);
	words.push_back(str);
}

void CVocFile::addWordToVocabulary(const SWord &word,std::vector<SWord> &vocabulary,
								   const bool &bSynonym,const enVocLang &enLang)
{
	if(bSynonym) {  // if synonym mode is enabled
		SWord synonym;
		synonym.numPasses=0;
		
		switch(enLang)
		{
		default:
		case vlLeft:
			// split synonyms from the left language
			synonym.lang2=word.lang2;
			for(size_t i=0;i<word.lang1.size();++i) {
				synonym.lang1.push_back(word.lang1[i]);
				vocabulary.push_back(synonym);
				synonym.lang1.clear();
			}
			break;
		case vlRight:
			// split synonyms from the right language
			synonym.lang1=word.lang1;
			for(size_t i=0;i<word.lang2.size();++i) {
				synonym.lang2.push_back(word.lang2[i]);
				vocabulary.push_back(synonym);
				synonym.lang2.clear();
			}
			break;
		}
	}
	else { // default behavior
		vocabulary.push_back(word);
	}
}

void CVocFile::AppendVocabulary(std::vector<SWord> &vocabulary,
								const bool &bSynonym,const enVocLang &enLang)		       
{
	ifstream ifFile(m_strFilename.c_str(),ios::in);
	string strLine;

	if(!ifFile)
    {
		cerr << CVocatraInfo::GetName() << ": ";
		cerr << _("Can't open voc-file") << " " << m_strFilename;
		cerr << ": ";
		perror("");
    }

	int nLine=0;
	while(getline(ifFile,strLine))
    {
		++nLine;
      
		size_t pos=checkLine(strLine);
		if(pos==string::npos)
		{
			cerr << CVocatraInfo::GetName() << ": ";
			cerr << m_strFilename << ":";
			cerr << nLine << ": ";
			cerr << _("error") << ": ";
			cerr << _("unexpected line format");
			cerr << endl;
		}
		else
		{
			if(pos>0)
			{
				SWord word;
				word.numPasses=0;
				seperateWords(strLine.substr(0,pos),word.lang1);
				seperateWords(strLine.substr(pos+1,strLine.size()-1),word.lang2);
				addWordToVocabulary(word,vocabulary,bSynonym,enLang);
			}
		}
    }
}
