/*
  Vocatra, a small and fast vocabulary trainer
  Copyright (C) 2006-2008 Oliver Sauder <os@esite.ch>
  
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#include <getopt.h>
#include <cstdlib>
#include <cstring>

#include "vocatra.H"
#include "vocatrainfo.H"
#include "vocoptions.H"

using namespace std;

static const struct option long_options[] =
{
	{ "version",  no_argument,       0, 'v' },
	{ "help",     no_argument,       0, 'h' },
	{ "mode",     required_argument, 0, 'm' },
	{ "language", required_argument, 0, 'l' },
	{ "passes",   required_argument, 0, 'p' },
	{ "debug",    no_argument,       0, 'd' },
	{ "stack",    no_argument,       0, 's' },
	{ "nocase",   no_argument,       0, 'c' },
	{ "synonym",  no_argument,       0, 'y' },
	{ "beep",     no_argument,       0, 'b' },
	{ 0,          0,                 0, 0   }
};

CVocOptions::CVocOptions()
{
	m_bDebug=false;
	m_bStack=false;
	m_bCaseMode=true;
	m_enMode=vmOrder;
	m_enLang=vlLeft;
	m_nNumPasses=1;
	m_bSynonym=false;
	m_bBeep=false;
	m_pVocFiles=NULL;
}

int CVocOptions::Parse(int argc,char *argv[])
{
	int option, option_index;

	while((option=getopt_long(argc,argv,"vhm:l:p:dscyb",long_options,&option_index))>=0)
	{
		switch(option)
		{
		case 'h': // help
			CVocatraInfo::PrintHelp();
			return 0;
		case 'v': // version
			CVocatraInfo::PrintVersion();
			return 0;
		case 'm': // mode
			if(strcmp(CVocatraInfo::GetOrderMode(),optarg)==0)
				m_enMode=vmOrder;
			else if(strcmp(CVocatraInfo::GetRandomMode(),optarg)==0)
				m_enMode=vmRandom;
			else if(strcmp(CVocatraInfo::GetAlphabeticalMode(),optarg)==0)
				m_enMode=vmAlphabetical;
			else
			{
				m_enMode=enVocMode(atoi(optarg));
				if(m_enMode!=vmOrder&&m_enMode!=vmRandom&&
				   m_enMode!=vmAlphabetical)
				{
					cerr << CVocatraInfo::GetName() << ": " << _("unknown mode");
					cerr << " " << optarg << endl;
					return 0;
				}
			}
			break;
		case 'l': // language
			if(strcmp(CVocatraInfo::GetLeftLang(),optarg)==0)
				m_enLang=vlLeft;
			else if(strcmp(CVocatraInfo::GetRightLang(),optarg)==0)
				m_enLang=vlRight;
			else
			{
				m_enLang=enVocLang(atoi(optarg));
				if(m_enLang!=vlLeft&&m_enLang!=vlRight)
				{
					cerr << CVocatraInfo::GetName() << ": ";
					cerr << _("unknown inquiry language");
					cerr << " " << optarg << endl;
					return 1;
				}
			}
			break;
		case 'p': // number of passes
			m_nNumPasses=atoi(optarg);
			if(m_nNumPasses<1)
			{
				cerr << CVocatraInfo::GetName() << ": ";
				cerr << _("unknown number of passes");
				cerr << " " << optarg << endl;
				return 1;
			}
			break;
		case 'd': // debug information
			m_bDebug=true;
			break;
		case 's': // stack mode
			m_bStack=true;
			break;
		case 'c': // case-insensitive mode (nocase)
			m_bCaseMode=false;
			break;
		case 'y': // synonym mode
			m_bSynonym=true;
			break;
		case 'b': // beep mode
			m_bBeep=true;
			break;
		case '?':
		default:
			CVocatraInfo::PrintUsage();
			return 1;
		}
	}

	if(optind==argc)
	{
		cerr << CVocatraInfo::GetName() << ": " << _("missing vocabulary files") << endl;
		CVocatraInfo::PrintUsage();
		return 0;
	}

	m_pVocFiles=&argv[optind];
	m_nNumFiles=argc-optind;

	return -1;
}
