/*
  Vocatra, a small and fast vocabulary trainer
  Copyright (C) 2008 Oliver Sauder <os@esite.ch>
  
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/ 

#ifndef _VOCPRINTER_H
#define _VOCPRINTER_H

/** Vocabulary Printer Class.
 *  This class handles all the functionality between writing to the console
 *  and Vocatra.
 */
class CVocPrinter
{
private:
	/** Helper function.
	 *  Prints line to stdout.
	 *  @param strLine string to be printed
	 */
	void printLine(std::string strLine);

	/** Helper function.
	 *  Generates a string with the given words
	 *  @param words vector with words to append to string
	 *  @result generated string
	 */
	std::string genWordString(const std::vector<std::string> &words);

	/** Helper function.
	 *  Plays a beep sound
	 */
	void beep();

public:
	/** Print Words function.
	 *  This function prints the words to stdout and separates them with a comma.
	 *  @param words vector with words to print.
	 */
	void PrintWords(const std::vector<std::string> &words);	

    /** Print correct string function.
	 *  This function prints a string to the standard output stream,
	 *  if the answer is correct.
	 */
	void PrintCorrectString();

	/** Print wrong string function.
	 *  This function prints a string to the standard output stream,
	 *  if the answer is wrong.
	 *  @param words vector with words to print
	 *  @param bBeep If true, function will cause beep sound
	 */
	void PrintWrongString(const std::vector<std::string> &words,
						  const bool &bBeep);

	/** Print start string function.
	 *  This function prints the start string to the standard output stream.
	 */
	void PrintStartString();

	/** Print end string function.
	 *	This function prints the end string to the standard output stream.
	 *  @param nWords number of learned vocabulary words
	 *  @param nInquiries number of word inquiries
	 *  @param nWrong number of wrong answers
	 *  @param nSecs number of seconds since the learning process has started
	 */
	void PrintEndString(size_t nWords,size_t nInquiries,size_t nWrong,size_t nSecs);
};

#endif  // _VOCPRINTER_H
