/*
  Vocatra, a small and fast vocabulary trainer
  Copyright (C) 2008 Oliver Sauder <os@esite.ch>
  
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/ 

#include "vocatra.H"
#include "vocprinter.H"

#include <string>
#include <iostream>
#include <sstream>

using namespace std;

void CVocPrinter::printLine(std::string strLine)
{
	cout << strLine << endl;
}

std::string CVocPrinter::genWordString(const std::vector<std::string> &words)
{
	string strResult = "";


	for(size_t i=0;i<words.size();++i)
    {
		strResult += words[i];
      
		if(i<(words.size()-1))
			strResult += ", ";
    }

	return strResult;
}

void CVocPrinter::beep()
{
	// send special beep character to output stream
	// causes the speaker to beep
	cout << "\a";
}

void CVocPrinter::PrintWords(const std::vector<std::string> &words)
{
	printLine(genWordString(words));
}

void CVocPrinter::PrintCorrectString()
{
	string strLine = "";
	// change output color to green
	strLine += "\033[32m";

	// add word correct
	strLine +=  _("correct");
	
	// change output color to default color
	strLine += "\033[0m";

	printLine(strLine);
}

void CVocPrinter::PrintWrongString(const std::vector<std::string> &words,
								   const bool &bBeep)
{
	string strLine = "";

	// if option beep is set, cause console to beep
	if(bBeep)
	{
		beep();
	}

	// change output color to red
	strLine += "\033[31m";

	strLine += _("wrong");

	// change output color to default color
	strLine += "\033[0m";
	
	// add solution string
	strLine += " (";
	strLine += _("Solution");
	strLine += ": ";
	
	// add word string to line
	strLine += genWordString(words);

	// add bracket
	strLine += ")";

	// finally: print line to stdout
	printLine(strLine);
}

void CVocPrinter::PrintStartString()
{
	string strLine = "";
	strLine += _("Start");
	strLine += "...";

	printLine(strLine);
}

void CVocPrinter::PrintEndString(size_t nWords,size_t nInquiries,
								 size_t nWrong,size_t nSecs)
{
	stringstream strStream;

	strStream << _("Finish") << " (";
	strStream << _("Words") << ": " << nWords << "; ";
	strStream << _("Inquiries") << ": " << nInquiries << "; ";
	strStream << _("Mistakes") << ": " << nWrong << "; ";
	strStream << _("Error rate") << ": " << nWrong*100/nInquiries << "%; ";

    // assign time format %m:%s
	size_t nModSecs=nSecs%60;
	string strSecsSep=nModSecs>=10?"":"0"; // if less then 10 seconds, add a zero
	strStream << _("Time") << ": " << nSecs/60 << ":" << strSecsSep << nModSecs << "'";
	
	strStream << ")";
	
	// print stream to stdout
	printLine(strStream.str());
}
